#
# spec file for package xalan-c
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xalan-c
BuildRequires:  Xerces-c-devel
BuildRequires:  gcc-c++
BuildRequires:  libicu-devel
Version:        1.11
Release:        4.18
%define tarver  %{version}
Summary:        An XSLT Transformation Engine in C++
License:        Apache-2.0
Group:          Productivity/Publishing/XML
Url:            http://xml.apache.org/xalan-c/
Source:         http://www.eu.apache.org/dist/xalan/xalan-c/sources/xalan_c-%{tarver}-src.tar.gz
Patch1:         %{name}-%{version}-lib64.patch
Patch2:         %{name}-%{version}-fixes.patch
Patch3:         %{name}-%{version}-optflags.patch
Patch4:         %{name}-%{version}-gcc4.patch
Patch5:         %{name}-%{version}-fix_build.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       Xalan-C = 1.11
Obsoletes:      Xalan-C <= 1.11

%description
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

%package -n libxalan-c111
# Requires:       Xalan-c = %{version}
Summary:        An XSLT Transformation Engine in C++
Group:          System/Libraries
Provides:       libXalan-c111 = 1.11
Obsoletes:      libXalan-c111 <= 1.11

%description -n libxalan-c111
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

%package -n libxalan-c-devel
Requires:       libxalan-c111 = %{version}
Provides:       Xalan-c-devel = 1.9
Obsoletes:      Xalan-c-devel <= 1.9
Provides:       libXalan-c-devel = 1.11
Obsoletes:      libXalan-c-devel <= 1.11
Summary:        An XSLT Transformation Engine in C++ - Development Files
Group:          Development/Libraries/C and C++

%description -n libxalan-c-devel
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and a robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

This package contains files needed for development with Xalanc

%prep
%setup -q -n xalan-c-%{version}
%patch1
%patch2
%patch3
%patch4
%patch5

%build
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
export SUSE_ASNEEDED=0
DIRS=$(find -type d)
[ -f configure.in ] && autoreconf -f -i  # libtoolize --copy --force
export XERCESCROOT=%{_prefix}
export XALANCROOT=$RPM_BUILD_DIR/xalan-c-%{version}/c
export ICUROOT=%{_prefix}
export RPM_OPT_FLAGS
cd c
chmod a+x runConfigure
chmod a+x conf*
%ifarch alpha ppc64 s390x sparc64 x86_64
BITSTOBUILD=64
%else
BITSTOBUILD=32
%endif
./runConfigure -p linux -c gcc -x g++ -t icu -m inmem -b "$BITSTOBUILD" -P %{_prefix} -C --libdir -C %{_libdir}
# Parallel build is broken, disable it for now
make
make samples
make tests

%install
export XERCESCROOT=%{_prefix}
export XALANCROOT=$RPM_BUILD_DIR/xalan-c-%{version}/c
export ICUROOT=%{_prefix}
pushd c
mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -m 755 bin/* $RPM_BUILD_ROOT%{_bindir}
ln -s testXSLT $RPM_BUILD_ROOT%{_bindir}/xsl-c
ln -s testXPath $RPM_BUILD_ROOT%{_bindir}/xpath-c
echo PREFIX=$RPM_BUILD_ROOT%{_prefix} >> Makefile.incl
echo prefix=$RPM_BUILD_ROOT%{_prefix} >> Makefile.incl
echo libdir=$RPM_BUILD_ROOT%{_libdir} >> Makefile.incl
echo "XSL_LIB_DIR=\${OUTDIR}/%{_lib}" >> Makefile.incl
echo "ICULIB_LOC=\${ICUROOT}/%{_lib}" >> Makefile.incl
make install
rm -f $RPM_BUILD_ROOT%{_libdir}/libicu*
popd

%post   -n libxalan-c111 -p /sbin/ldconfig

%postun -n libxalan-c111 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc c/LICENSE
%{_bindir}/*

%files -n libxalan-c111
%defattr(-, root, root)
%{_libdir}/*.so.*

%files -n libxalan-c-devel
%defattr(-,root,root)
%{_includedir}/xalanc/
%{_libdir}/*.so

%changelog
* Tue Mar 10 2015 matwey.kornilov@gmail.com
- Update to 1.11
- Drop xalan-c-1.10.0-gcc46.patch: upstreamed
- Frop xalan-c-svn-20090415.patch: upstreamed
- Refresh and rename the following patches
  * xalan-c-1.10.0-lib64.patch -> xalan-c-1.11-lib64.patch
  * xalan-c-1.10.0-fix_build.patch -> xalan-c-1.11-fix_build.patch
  * xalan-c-1.10.0-optflags.patch -> xalan-c-1.11-optflags.patch
  * xalan-c-1.10.0-fixes.patch -> xalan-c-1.11-fixes.patch
  * xalan-c-1.10.0-gcc4.patch -> xalan-c-1.11-gcc4.patch
* Thu Dec 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use System/Libraries for shlibs
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon May  2 2011 idoenmez@novell.com
- Add xalan-c-1.10.0-gcc46.patch to fix compilation with gcc 4.6
* Sun Nov 15 2009 meissner@suse.de
- refresh patch with fuzz=0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Apr 15 2009 ro@suse.de
- rename subpackages (X to x)
- update to svn to try to build with current xerces
* Mon Sep  1 2008 aj@suse.de
- Do not build in parallel.
* Thu Aug 14 2008 prusnak@suse.cz
- cleaned spec file (and renamed libXalan-c-110 to libXalan-c110)
* Tue Dec 18 2007 zpetrova@suse.cz
- Fixed Requires of lib subpackage.
* Wed Oct  3 2007 zpetrova@suse.cz
- fixed build.
* Tue Aug  7 2007 mrueckert@suse.de
- revert %%check change
* Mon Aug  6 2007 mrueckert@suse.de
- fixed buildrequires (using the old package name. it is still
  provided)
- ldconfig should be run for the new library package libXalan-c-110
- move make test into %%check
* Mon Aug  6 2007 mrueckert@suse.de
- added provides/obsoletes for the package rename
* Mon Aug  6 2007 zpetrova@suse.cz
- split to libXalan-c-110, lib-Xalan-c-devel according to
  Shared library guidelines.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 zpetrova@suse.cz
- update to 1.10
* Tue May  3 2005 uli@suse.de
- fixed to build with GCC4
* Tue Mar 22 2005 didge@suse.de
- added new patch by Robert Schiele (Bug #64605)
* Mon Jan 24 2005 ro@suse.de
- fix lib64 build
* Tue Jan 11 2005 didge@suse.de
- new version 1.9
* Mon Dec 20 2004 didge@suse.de
- removed soname patch as it isn't needed anymore
* Thu Dec  9 2004 didge@suse.de
- added patch by Robert Schiele to rename include path from xalan
  to xalanc
* Mon Aug  9 2004 didge@suse.de
- new version 1.8
- soname patch adapted
* Wed May 12 2004 didge@suse.de
- patch added to fix #40176
- fixed #40178 by adding expat to neededforbuild
* Fri Feb 13 2004 meissner@suse.de
- Fixed lib64 problem.
* Tue Feb 10 2004 didge@suse.de
- Update to version 1.7
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Aug 29 2003 nashif@suse.de
- #29608: Symlink libs instead of copying them
* Tue Aug 26 2003 nashif@suse.de
- Reduced docs
* Tue Aug  5 2003 nashif@suse.de
- Update to version 1.6
* Thu May 29 2003 nashif@suse.de
- Update to version 1.5
* Tue Jan 21 2003 nashif@suse.de
- Adapted to use latest Xerces-c
- Updated sources to real 1.4
* Fri May 17 2002 nashif@suse.de
- Fixed for lib64
* Wed May 15 2002 nashif@suse.de
- Java not needed for build
* Tue May 14 2002 nashif@suse.de
- Update to 1.4 CVS which actually compiles
* Fri Mar  8 2002 sf@suse.de
- removed a wrong #define to build with gcc3.x
* Thu Jan 31 2002 nashif@suse.de
- Update to version 1.3
- Use the source from CVS (version 1.3)
- Create docs using doxygen
* Thu Oct 11 2001 nashif@suse.de
- Initial Release (1.2)
